pub enum ConstantByte {
Uninit,
Value(u8),
Provenance(ConstantByteProvenance, u8),
}Expand description
A byte of an evaluated constant, in the MiniRust sense.
Variants
Uninit
An uninitialized byte (e.g. padding, or the bytes of a union not covered by the active field).
Value(u8)
A concrete byte value.
Provenance(ConstantByteProvenance, u8)
A byte that is part of a pointer with provenance. The u8 is the offset of this byte
within the pointer.