Struct VariantIdx
pub struct VariantIdx {
private_use_as_methods_instead: u32,
}Expand description
The source-order index of a variant in a type.
For enums, these are always 0..variant_count, regardless of any
custom discriminants that may have been defined, and including any
variants that may end up uninhabited due to field types. (Some of the
variants may not be present in a monomorphized ABI [Variants], but
those skipped variants are always counted when determining the index.)
structs, tuples, and unionss are considered to have a single variant
with variant index zero, aka [FIRST_VARIANT].
Fields
private_use_as_methods_instead: u32Trait Implementations
Sourceimpl<S> SInto<S, VariantIdx> for VariantIdx
impl<S> SInto<S, VariantIdx> for VariantIdx
fn sinto(&self, _s: &S) -> VariantIdx